// usage: $ a 'macro/shift.C("run","0100")'
// or
// usage: $ a
//      : artemis [] .x macro/shift.C("run","0100")

#include "chkmuxpos.C"
#include "xfitg.C"
#include "xstatus.C"

// scaler info
const TString scaler_names[32] = {
    "Ungate",
    "Gate",
    "Beam x SSD",
    "Beam / n ",
    "F3PPACa",
    "F3PPACb",
    "SSD-OR",
    "Clock 10Hz",
    "-",
    "Pileup",
    "Beam",
    "-",
    "Single-Pad SSD",
    "-",
    "MUX OR",
    "tel4/5 dE",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "N/A",
    "Clock 10Hz"};

const Bool_t do_save = false;

void shift(TString RUNNAME = "", TString RUNNUM = "") {
    TString dummy = "dummy";

    //=====================================================
    // load steering file and event loop
    {
        gROOT->ProcessLine(Form("add steering/shift.yaml NAME=%s NUM=%s", RUNNAME.Data(), RUNNUM.Data()));
        art::TLoopManager::Instance()->GetLoop()->Resume();

        gROOT->ProcessLine("cd"); // not necessary
    }

    //=====================================================
    // histogram check
    {
        // beam purity check
        gROOT->ProcessLine("zone");
        gROOT->ProcessLine("gcom beam purity check");
        gROOT->ProcessLine("cd 0");
        gROOT->ProcessLine("ht 6");
        gPad->Update();
        gROOT->ProcessLine("xstatus");
        gPad->Update();
        if (do_save)
            gROOT->ProcessLine("save");
        std::cout << "please enter something to proceed [y, exit] ";
        std::cin >> dummy;
        if (dummy == "exit")
            return;
        gROOT->ProcessLine("cd");

        // check beam information
        gROOT->ProcessLine("zone 3 2");
        gROOT->ProcessLine("gcom beam information");
        gROOT->ProcessLine("ht 0/0");
        gROOT->ProcessLine("ht 0/2");
        gROOT->ProcessLine("ht 0/13");
        gROOT->ProcessLine("ht 0/14");
        gROOT->ProcessLine("ht 0/7");
        gROOT->ProcessLine("ht 0/11");
        gPad->Update();
        if (do_save)
            gROOT->ProcessLine("save");
        std::cout << "please enter something to proceed [y, exit] ";
        std::cin >> dummy;
        if (dummy == "exit")
            return;

        // Telescope dE-E plot(13N coin)
        gROOT->ProcessLine("zone 3 2");
        gROOT->ProcessLine("gcom dE-E plot");
        gROOT->ProcessLine("ht 0/21");
        gROOT->ProcessLine("ht 0/22");
        gROOT->ProcessLine("ht 0/23");
        gROOT->ProcessLine("ht 0/24");
        gROOT->ProcessLine("ht 0/25");
        gPad->Update();
        if (do_save)
            gROOT->ProcessLine("save");
        std::cout << "please enter something to proceed [y, exit] ";
        std::cin >> dummy;
        if (dummy == "exit")
            return;

        // raw data check tel1
        gROOT->ProcessLine("zone 3 2");
        gROOT->ProcessLine("gcom raw data check telescope1");
        gROOT->ProcessLine("ht 3/6");
        gROOT->ProcessLine("ht 3/7");
        gROOT->ProcessLine("ht 3/8");
        gROOT->ProcessLine("ht 3/12");
        gROOT->ProcessLine("ht 3/13");
        gROOT->ProcessLine("ht 3/14");
        gROOT->ProcessLine("lgz");
        gPad->Update();
        if (do_save)
            gROOT->ProcessLine("save");
        std::cout << "please enter something to proceed [y, exit] ";
        std::cin >> dummy;
        if (dummy == "exit")
            return;

        // raw data check tel2
        gROOT->ProcessLine("zone 3 3");
        gROOT->ProcessLine("gcom raw data check telescope2");
        gROOT->ProcessLine("cd 5");

        gROOT->ProcessLine("ht 0");
        TH1F *hmux2_1 = (TH1F *)gDirectory->GetList()->At(0);
        chkmuxpos(hmux2_1, "prm/tel2/pos_dEX/current");
        gROOT->ProcessLine("ht 1");
        TH1F *hmux2_2 = (TH1F *)gDirectory->GetList()->At(1);
        chkmuxpos(hmux2_2, "prm/tel2/pos_dEY/current");
        gROOT->ProcessLine("ht 10");
        gROOT->ProcessLine("ht 11");
        gROOT->ProcessLine("ht 12");
        gROOT->ProcessLine("ht 16");
        gROOT->ProcessLine("ht 17");
        gROOT->ProcessLine("ht 18");
        gROOT->ProcessLine("lgz");
        gPad->Update();
        if (do_save)
            gROOT->ProcessLine("save");
        std::cout << "please enter something to proceed [y, exit] ";
        std::cin >> dummy;
        if (dummy == "exit")
            return;
        gROOT->ProcessLine("cd");

        // raw data check tel3
        gROOT->ProcessLine("zone 3 3");
        gROOT->ProcessLine("gcom raw data check telescope3");
        gROOT->ProcessLine("cd 7");

        gROOT->ProcessLine("ht 0");
        TH1F *hmux3_1 = (TH1F *)gDirectory->GetList()->At(0);
        chkmuxpos(hmux3_1, "prm/tel3/pos_dEX/current");
        gROOT->ProcessLine("ht 1");
        TH1F *hmux3_2 = (TH1F *)gDirectory->GetList()->At(1);
        chkmuxpos(hmux3_2, "prm/tel3/pos_dEY/current");
        gROOT->ProcessLine("ht 10");
        gROOT->ProcessLine("ht 11");
        gROOT->ProcessLine("ht 12");
        gROOT->ProcessLine("ht 16");
        gROOT->ProcessLine("ht 17");
        gROOT->ProcessLine("ht 18");
        gROOT->ProcessLine("lgz");
        gPad->Update();
        if (do_save)
            gROOT->ProcessLine("save");
        std::cout << "please enter something to proceed [y, exit] ";
        std::cin >> dummy;
        if (dummy == "exit")
            return;
        gROOT->ProcessLine("cd");

        // raw data check tel4
        gROOT->ProcessLine("zone 3 2");
        gROOT->ProcessLine("gcom raw data check telescope4");
        gROOT->ProcessLine("ht 9/6");
        gROOT->ProcessLine("ht 9/7");
        gROOT->ProcessLine("ht 9/8");
        gROOT->ProcessLine("ht 9/12");
        gROOT->ProcessLine("ht 9/13");
        gROOT->ProcessLine("ht 9/14");
        //gROOT->ProcessLine("lgz");
        gPad->Update();
        if (do_save)
            gROOT->ProcessLine("save");
        std::cout << "please enter something to proceed [y, exit] ";
        std::cin >> dummy;
        if (dummy == "exit")
            return;

        // raw data check tel5
        gROOT->ProcessLine("zone 3 2");
        gROOT->ProcessLine("gcom raw data check telescope5");
        gROOT->ProcessLine("ht 11/6");
        gROOT->ProcessLine("ht 11/7");
        gROOT->ProcessLine("ht 11/8");
        gROOT->ProcessLine("ht 11/12");
        gROOT->ProcessLine("ht 11/13");
        gROOT->ProcessLine("ht 11/14");
        //gROOT->ProcessLine("lgz");
        gPad->Update();
        if (do_save)
            gROOT->ProcessLine("save");
        std::cout << "please enter something to proceed [y, exit] ";
        std::cin >> dummy;
        if (dummy == "exit")
            return;
    }

    //=====================================================
    // scaler section
    {
        // fcd 0
        TList *const list = static_cast<TList *>(gROOT->GetListOfFiles());
        TFile *file = dynamic_cast<TFile *>(list->At(0));
        file->cd();

        art::TArtTree *tree;
        file->GetObject("tree", tree);
        Long64_t nEntries = tree->GetEntries();
        Long64_t useEntries = nEntries < 100000 ? nEntries : 100000;

        art::TScalerData *scaler_data = nullptr;
        tree->SetBranchAddress("scatot", &scaler_data);

        Double_t scaler[32] = {0.0};
        tree->GetEntry(0);
        for (Int_t i = 0; i < 32; i++) {
            scaler[i] = scaler_data->GetValue(i);
        }
        // tree->GetEntry(nEntries - 1);
        tree->GetEntry(useEntries - 1);
        for (Int_t i = 0; i < 32; i++) {
            scaler[i] = scaler_data->GetValue(i) - scaler[i];
        }

        // show count rate
        std::cout << "=================================================" << std::endl;
        std::cout << "\033[1mCount rate (cps) recorded by SIS3820\033[0m" << std::endl;
        for (Int_t i = 0; i < 32; i++) {
            scaler[i] = scaler[i] / (scaler[31] * 0.1);
            std::cout << Form("    %-15s: %15.3f", scaler_names[i].Data(), scaler[i]) << std::endl;
        }

        gROOT->ProcessLine("cd");
    }
}
